struct ByteCount<C> {
writer: ByteCounterWriter<C>,
}Fields
writer: ByteCounterWriter<C>Trait Implementations
Sourceimpl<C: Counter> ByteWrite for ByteCount<C>
impl<C: Counter> ByteWrite for ByteCount<C>
Sourcefn write<V: Primitive>(&mut self, _value: V) -> Result<()>
fn write<V: Primitive>(&mut self, _value: V) -> Result<()>
Writes whole numeric value to stream Read more
Sourcefn write_as<F: Endianness, V: Primitive>(&mut self, _value: V) -> Result<()>
fn write_as<F: Endianness, V: Primitive>(&mut self, _value: V) -> Result<()>
Writes whole numeric value to stream in a potentially different endianness Read more
Sourcefn write_bytes(&mut self, buf: &[u8]) -> Result<()>
fn write_bytes(&mut self, buf: &[u8]) -> Result<()>
Writes the entirety of a byte buffer to the stream. Read more
Sourcefn pad(&mut self, bytes: u32) -> Result<()>
fn pad(&mut self, bytes: u32) -> Result<()>
Pads the stream by writing 0 over the given number of bytes. Read more
Sourcefn writer_ref(&mut self) -> &mut dyn Write
fn writer_ref(&mut self) -> &mut dyn Write
Returns mutable reference to underlying writer
Sourcefn build<T: ToByteStream>(&mut self, build: &T) -> Result<(), T::Error>
fn build<T: ToByteStream>(&mut self, build: &T) -> Result<(), T::Error>
Builds and writes complex type
Sourcefn build_with<'a, T: ToByteStreamWith<'a>>(
&mut self,
build: &T,
context: &T::Context,
) -> Result<(), T::Error>
fn build_with<'a, T: ToByteStreamWith<'a>>( &mut self, build: &T, context: &T::Context, ) -> Result<(), T::Error>
Builds and writes complex type with context
Sourcefn build_using<T: ToByteStreamUsing>(
&mut self,
build: &T,
context: T::Context,
) -> Result<(), T::Error>
fn build_using<T: ToByteStreamUsing>( &mut self, build: &T, context: T::Context, ) -> Result<(), T::Error>
Builds and writes complex type with owned context